<?php

###############################################################################
# finnish.php
# This is the Finnish language page for GeekLog!
#
# Copyright (C) 2004 Jussi Josefsson
# 20031012 - Version 1.0 - Geeklog 1.3.8
# 20040217 - Version 1.1 - Geeklog 1.3.9rc1
# ihra@iki.fi
#
# Converted to Unicode (UTF-8) by Samuel Stone <sam@stonemicro.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'utf-8';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Kirjoittaja:',
    2 => 'lue lisää',
    3 => 'kommentti(a)',
    4 => 'Muokkaa',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Ylläpidon toiminnot:',
    10 => 'Lähetyksiä',
    11 => 'Artikkeleja',
    12 => 'Blokkeja',
    13 => 'Aiheita',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Käyttäjiä',
    18 => 'SQL kysely',
    19 => 'Kirjaudu ulos',
    20 => 'Käyttäjän tiedot:',
    21 => 'Käyttäjän nimi',
    22 => 'Tunnus',
    23 => 'Turvallisuustaso',
    24 => 'Tuntematon',
    25 => 'Vastaa',
    26 => 'Oheiset kommentit ovat kirjoittajiensa omaisuutta. Sivusto ei ole vastuussa kirjoittajien sanomisista.',
    27 => 'Uusin kirjoitus',
    28 => 'Poista',
    29 => 'Ei käyttäjän lähettämiä kommentteja',
    30 => 'Vanhemmat artikkelit',
    31 => 'Sallitut HTML tagit:',
    32 => 'Virhe, virheellinen käyttäjänimi',
    33 => 'Virhe, logiin ei voi kirjoittaa',
    34 => 'Virhe',
    35 => 'Kirjaudu ulos',
    36 => 'on',
    37 => 'Ei käyttäjän kirjoituksia',
    38 => 'Content Syndication',
    39 => 'Virkistä',
    40 => 'You have <tt>register_globals = Off</tt> in your <tt>php.ini</tt>. However, Geeklog requires <tt>register_globals</tt> to be <strong>on</strong>. Before you continue, please set it to <strong>on</strong> and restart your web server.',
    41 => 'Vieraita sivustolla',
    42 => 'Tekijä:',
    43 => 'Vastaa tähän',
    44 => 'Edellinen',
    45 => 'MySQL virhe numeroltaan',
    46 => 'MySQL virhe viesti',
    47 => 'Käyttäjän toiminnot',
    48 => 'Omat tiedot',
    49 => 'Asetukset',
    50 => 'Virhe SQL lauseessa',
    51 => 'apua',
    52 => 'Uusi',
    53 => 'Ylläpito',
    54 => 'Tiedostoa ei voinut avata.',
    55 => 'Virhe',
    56 => 'Äänestä',
    57 => 'Salasana',
    58 => 'Kirjaudu',
    59 => "Ei tunnusta vielä? Kirjaudu <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">uutena käyttäjänä</a>",
    60 => 'Lähetä kommentti',
    61 => 'Luo uusi käyttäjätili',
    62 => 'sanaa',
    63 => 'Kommenttien asetukset',
    64 => 'Lähetä artikkeli sähköpostitse ystävälle',
    65 => 'Näytä tulostettava versio',
    66 => '',
    67 => 'Tervetuloa sivustolle',
    68 => 'etusivu',
    69 => 'yhteystiedot',
    70 => 'etsi',
    71 => 'lähetä artikkeli',
    72 => 'verkkoresurssit',
    73 => '',
    74 => '',
    75 => 'laajennettu etsintä',
    76 => 'sivuston tilastot',
    77 => 'Laajennukset',
    78 => '',
    79 => 'Uutta sivustolla',
    80 => 'artikkelia viimeiseen',
    81 => 'artikkeli viimeiseen',
    82 => 'tuntiin',
    83 => 'KOMMENTIT',
    84 => '',
    85 => 'viimeisenä 48 tuntina',
    86 => 'Ei uusia kommentteja',
    87 => 'viimeiseen 2 viikkoon',
    88 => '',
    89 => '',
    90 => 'Etusivu',
    91 => 'Sivu luotu ',
    92 => 'sekunnissa',
    93 => 'Copyright',
    94 => 'All trademarks and copyrights on this page are owned by their respective owners.',
    95 => 'Moottorina toimii',
    96 => 'Ryhmiä',
    97 => 'Sana lista',
    98 => 'Laajennuksia',
    99 => 'ARTIKKELIT',
    100 => 'Ei uusia artikkeleita',
    101 => '',
    102 => '',
    103 => 'DB varmuuskopiointi',
    104 => 'by',
    105 => 'Sähköpostia käyttäjille',
    106 => 'Katselukertoja',
    107 => 'GL versiotesti',
    108 => 'Tyhjennä välimuisti',
    109 => 'Report abuse',
    110 => 'Report this post to the site admin',
    111 => '',
    112 => 'Registered Users',
    113 => 'Documentation',
    114 => 'TRACKBACKS',
    115 => 'No new trackback comments',
    116 => 'Trackback',
    117 => 'Directory',
    118 => 'Please continue reading on the next page:',
    119 => "Lost your <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">password</a>?",
    120 => 'Permanent link to this comment',
    121 => 'Comments (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'All HTML is allowed',
    124 => 'Click to delete all checked items',
    125 => 'Are you sure you want to Delete all checked items?',
    126 => 'Select or de-select all items',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Lähetä kommentti',
    2 => 'Lähetyksen muoto',
    3 => 'Kirjaudu ulos',
    4 => 'Luo käyttäjätili',
    5 => 'Käyttäjänimi',
    6 => 'Sivustolle voi lähettää kommentteja vain rekisteröityneet käyttäjät. Jos sinulla ei ole käyttäjätiliä sivustolla, voit tehdä tilin käyttämällä alla olevaa lomaketta.',
    7 => 'Viimeisin kommenttisi kirjoitettiin ',
    8 => " sekuntia sitten. Sivusto vaatii vähintään {$_CONF['commentspeedlimit']} sekuntia kommenttien välillä",
    9 => 'Kommentti',
    10 => 'Send Report',
    11 => 'Lähetä kommentti',
    12 => 'Täytä otsikko ja kommentti -kentät, ne ovat pakollisia kommenttia lähetettäessä.',
    13 => 'Omat tietosi',
    14 => 'Esikatselu',
    15 => 'Report this post',
    16 => 'Otsikko',
    17 => 'Virhe',
    18 => 'Tärkeitä huomioita',
    19 => 'Yritä pysyä aiheessa.',
    20 => 'Pyri vastaamaan muiden lähettämiin kommentteihin uuden kommenttisäikeen aloittamisen sijaan.',
    21 => 'Lue muiden lähettämät viestit ennen oman kommentin postittamista toiston estämiseksi.',
    22 => 'Nimeä viesti selkeästi ja kuvaavasti.',
    23 => 'Sähköpostiosoitteesi EI tule julkisesti näkyville.',
    24 => 'Tuntematon käyttäjä',
    25 => 'Are you sure you want to report this post to the site admin?',
    26 => '%s reported the following abusive comment post:',
    27 => 'Abuse report',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Tiedot käyttäjästä',
    2 => 'Käyttäjän nimi',
    3 => 'Koko nimi',
    4 => 'Salasana',
    5 => 'Sähköposti',
    6 => 'Kotisivu',
    7 => 'Tiedot',
    8 => 'PGP avain',
    9 => 'Tallenna tiedot',
    10 => 'Viimeiset 10 kommenttiä käyttäjältä',
    11 => 'Ei käyttäjän lähettämiä kommentteja',
    12 => 'Asetukset käyttäjälle',
    13 => 'Lähetä päivittäinen yhteenveto sähköpostitse',
    14 => 'Tämä salasana on satunnaisgeneraattorin tuottama. On suositeltavaa vaihtaa salasana toiseen välittömästi. Vaihtaaksesi salasanan, kirjaudu sivustolle ja valitse Omat tiedot käyttäjän toiminnoista.',
    15 => "{$_CONF['site_name']} käyttäjätili on luotu. Käyttääksesi tiliä, kirjaudu sisään allaolevin tiedoin. Säästä tämä sähköposti tulevaa käyttöä varten.",
    16 => 'Omat tiedot',
    17 => 'Tiliä ei ole olemassa',
    18 => 'Sähköposti-osoite ei ole tunnu olevan oikeanmuotoinen osoite',
    19 => 'Syötetty käyttäjänimi tai sähköposti ovat jo käytössä',
    20 => 'Sähköposti-osoite ei ole oikea sähköposti-osoite',
    21 => 'Virhe',
    22 => "Rekisteröidy sivustolle {$_CONF['site_name']}!",
    23 => "Luomalla sivustolle {$_CONF['site_name']} käyttäjätilin voit itse lähettää artikkeleita tai kommentteja. Ilman tiliä voit lähettää viestejä vain tuntemattomana. Huomaa että sähköpostiosoitettasi ei <b><i>koskaan</i></b> näytetä julkisesti sivustolla.",
    24 => 'Salasanasi lähetetään syöttämääsi sähköpostiosoitteeseen.',
    25 => 'Unohditko salasanasi?',
    26 => 'Syötä <em>joko</em> käyttäjänimesi <em>tai</em> sähköposti-osoitteesi jotka syötit rekisteröityessäsi ja valitse Lähetä salasana. Ohjeet uuden salasanan asettamiseksi lähetetään sähköpostitse tilin osoitteeseen.',
    27 => 'Rekisteröidy!',
    28 => 'Lähetä salasana',
    29 => 'kirjauduit ulos sivustolta',
    30 => 'kirjauduit sisään sivustolle',
    31 => 'Toiminto vaatii rekisteröitymistä',
    32 => 'Allekirjoitus',
    33 => 'Ei julkisesti näkyvä',
    34 => 'Oikea nimesi',
    35 => 'Kirjoita uusi salasana jos haluat vaihtaa vanhan',
    36 => 'Alkaa http://',
    37 => 'Lisätty kommentteihisi',
    38 => 'Kaikki elämästäsi! Kaikki voivat lukea tämän',
    39 => 'Julkinen PGP avain jaettavaksi',
    40 => 'Ei aiheiden kuvakkeita',
    41 => 'Halukas moderoijaksi',
    42 => 'Päiväyksen muoto',
    43 => 'Artikkelien maksimimäärä',
    44 => 'Ei laatikkoja',
    45 => 'Näytä asetukset tilille',
    46 => 'Poisjätettävät kohteet tilille',
    47 => 'Uutislaatikon asetukset tilille',
    48 => 'Aiheet',
    49 => 'Ei kuvakkeita artikkeleissa',
    50 => 'Poista rasti jos et ole kiinnostunut',
    51 => 'Vain uutiset',
    52 => 'Oletus on',
    53 => 'Vastaanota päivän tarina joka yö',
    54 => 'Valitse aiheet ja kirjoittajat joita et halua nähdä.',
    55 => 'Jättämällä kaikki laatikot valitsematta, käytetään oletusarvoja. Jos alat rastittamaan valintoja, muista valita kaikki haluamasi, koska oletusarvot ohitetaan. Oletusarvot näytetään lihavoituina.',
    56 => 'Kirjoittajat',
    57 => 'Näyttötila',
    58 => 'Lajittelujärjestys',
    59 => 'Kommenttien rajoitus',
    60 => 'Miten haluat kommenttisi näytettävän?',
    61 => 'Uusimmat vai vanhimmat ensin?',
    62 => 'Oletus on 100',
    63 => "Salasanasi on lähetetty sähköpostitse. Seuraa viestissä olevia ohjeita ja kiitos kun käytät sivustoa {$_CONF['site_name']}",
    64 => 'Kommenttien astukset käyttäjälle',
    65 => 'Yritä kirjautua uudestaan',
    66 => "Kirjoitit sisäänkirjautuessa jotain väärin. Yritä kirjautua uudelleen. Oletko <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">uusi käyttäjä</a>?",
    67 => 'Liittynyt',
    68 => 'Säilytä tiedot',
    69 => 'Kuinka kauan sivuston tulee muistaa tietosi kirjautumisen jälkeen?',
    70 => "Muokkaa ulkoasua ja asetuksia sivustolle {$_CONF['site_name']}",
    71 => "Yksi tämän sivuston ({$_CONF['site_name']}) parhaista ominaisuuksista on muokattavuus - voit muokata haluamasi ulkoasun ja sisällön sivustolle. Hyödyntääksesi ominaisuuksia sinun tulee ensiksi <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">rekisteröityä</a> sivustolle {$_CONF['site_name']}.  Oletko jo rekisteröitynyt? Kirjaudu sisään käyttäen vasemmalla olevaa lomaketta!",
    72 => 'Teema',
    73 => 'Kieli',
    74 => 'Vaihda sivuston ulkoasua!',
    75 => 'Sähköpostitse lähetettävät uutiset',
    76 => 'Valitsemalla aiheet alla olevasta listasta, saat uudet aiheisiin liittyvät uutiset sähköpostitse itsellesi kerran päivässä. Valitse vain aiheet joista olet kiinnostunut!',
    77 => 'Kuva',
    78 => 'Lisää kuva itsestäsi!',
    79 => 'Rastita tämä poistaaksesi kuvan',
    80 => 'Kirjaudu',
    81 => 'Lähetä sähköpostitse',
    82 => 'Viimeiset 10 tarinaa käyttäjältä',
    83 => 'Tilastot kirjoituksista käyttäjältä',
    84 => 'Artikkeleita yhteensä:',
    85 => 'Kommentteja yhteensä:',
    86 => 'Etsi kaikki postitukset käyttäjältä',
    87 => 'Nimesi jolla olet kirjautunut',
    88 => "Joku (mahdollisesti sinä itse) on pyytänyt uutta salasanaa tilillesi \"%s\" sivustolla {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nJos haluat vaihtaa salasanan, valitse seuraava linkki:\n\n",
    89 => "Jos et halua tehdä näin, ohita tämä viesti ja pyyntö evätään (salasanasi pysyy muuttumattomana).\n\n",
    90 => 'Voit kirjoittaa tilisi uuden salasanan alle, Huomaa että vanha salasanasi on yhä voimassa kunnes lähetät tämän lomakkeen.',
    91 => 'Aseta uusi salasana',
    92 => 'Kirjoita uusi salasana',
    93 => 'Edellinen pyyntösi salasanan vaihtamiseksi tapahtui %d sekuntia sitten. Sivusto vaatii ainakin %d sekunnin viiveen vaihtojen välillä.',
    94 => 'Poista tili "%s"',
    95 => 'Valitse "poista tili" nappi alta poistaaksesi tietosi tietokannasta. Huomaa että kaikki postittamasi artikkelit ja kommentit <strong>eivät</strong> poistu, mutta niiden kirjoittajaksi merkitään "tuntematon".',
    96 => 'poista tili',
    97 => 'Vahvista tilin poistaminen',
    98 => 'Oletko varma että haluat poistaa tilisi? Poistamalla käyttäjätilin et voi kirjautua sivustolle uudestaan (paitsi tekemällä uuden tilin). Jos olet varma, valitse "poista tili" alta.',
    99 => 'Yksityisyyden vaihtoehdot tilille',
    100 => 'Ylläpidon viestit',
    101 => 'Salli ylläpidon lähettämät sähköpostit',
    102 => 'Käyttäjien viestit',
    103 => 'Salli muiden käyttäjien lähettämät sähköpostit',
    104 => 'Näytä linjalla -tila',
    105 => 'Näy Ketä on linjalla -lohkossa',
    106 => 'Location',
    107 => 'Shown in your public profile',
    108 => 'Confirm new password',
    109 => 'Enter the New password again here',
    110 => 'Current Password',
    111 => 'Please enter your Current password',
    112 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    113 => 'Login Attempt Failed',
    114 => 'Account Disabled',
    115 => 'Your account has been disabled, you may not login. Please contact an Administrator.',
    116 => 'Account Awaiting Activation',
    117 => 'Your account is currently awaiting activation by an administrator. You will not be able to login until your account has been approved.',
    118 => "Your {$_CONF['site_name']} account has now been activated by an administrator. You may now login to the site at the url below using your username (<username>) and password as previously emailed to you.",
    119 => 'If you have forgotten your password, you may request a new one at this url:',
    120 => 'Account Activated',
    121 => 'Service',
    122 => 'Sorry, new user registration is disabled',
    123 => "Are you a <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">new user</a>?",
    124 => 'Confirm Email',
    125 => 'You have to enter the same email address in both fields!',
    126 => 'Please repeat for confirmation',
    127 => 'To change any of these settings, you will have to enter your current password.',
    128 => 'Your Name',
    129 => 'Password &amp; Email',
    130 => 'About You',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Comment Display',
    134 => 'Comment Options',
    135 => '<li>Default mode for how comments will be displayed</li><li>Default order to display comments</li><li>Set maximum number of comments to show - default is 100</li>',
    136 => 'Exclude Topics and Authors',
    137 => 'Filter Story Content',
    138 => 'Misc Settings',
    139 => 'Layout and Language',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics<li>Set the maximum number of stories to show per page</li><li>Set your theme and perferred date format</li>',
    141 => 'Privacy Settings',
    142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
    143 => 'Filter Block Content',
    144 => 'Show & hide boxes',
    145 => 'Your Public Profile',
    146 => 'Password and email',
    147 => 'Edit your account password, email and autologin feature. You will need to enter the same password or email address twice as a confirmation.',
    148 => 'User Information',
    149 => 'Modify your user information that will be shown to other users.<li>The signature will be added to any comments or forum posts you made</li><li>The BIO is a brief summary of yourself to share</li><li>Share your PGP Key</li>',
    150 => 'Warning: Javascript recommended for enhanced functionality',
    156 => 'Delete Account',
    157 => 'Delete Option',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Ei näytettäviä uutisia',
    2 => 'Ei näytettäviä uutisiä. Joko aiheesta ei ole uutisia tai asetuksesi voivat olla liian rajoittavia',
    3 => ' aiheesta %s',
    4 => 'Päivän artikkeli',
    5 => 'Seuraava',
    6 => 'Edellinen',
    7 => 'First',
    8 => 'Last'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Virhe viestiä lähetettäessä. Yritä uudelleen.',
    2 => 'Viesti lähetetty onnistuneesti.',
    3 => 'Varmista että vastausosoite-kentässä on oikea sähköpostiosoite.',
    4 => 'Täytä nimesi, vastausosoite, aihe sekä viesti-kentät',
    5 => 'Virhe: valittua käyttäjää ei löydy.',
    6 => 'Tapahtui virhe käsittelyssä.',
    7 => 'Profiili käyttäjälle',
    8 => 'Käyttäjänimi',
    9 => 'Käyttäjän URL',
    10 => 'Lähetä viesti käyttäjälle',
    11 => 'Nimesi:',
    12 => 'Vastausosoite:',
    13 => 'Aihe:',
    14 => 'Viesti:',
    15 => 'HTML koodeja ei käännetä.',
    16 => 'Lähetä viesti',
    17 => 'Lähetä artikkeli ystävälle',
    18 => 'Käyttäjälle',
    19 => 'Sähköpostiosoitteeseen',
    20 => 'Lähettäjän nimi',
    21 => 'Lähettäjän sähköpostiosoite',
    22 => 'Kaikki kentät on täytettävä',
    23 => "Tämän sähköpostin lähetti sinulle %s at %s koska hän ajatteli artikkelin osoitteesta {$_CONF['site_url']} kiinnostavan sinua.  Tämä ei ole roskapostia ja lähetyksessä käytettyjä sähköpostiosoitteita ei tallenneta myöhempää käyttöä varten.",
    24 => 'Kommentoi artikkelia osoitteessa',
    25 => 'Sinun taytyy olla kirjautuneena sivustolle käyttääksesi ominaisuutta. Vaatimalla kirjautumista estetään järjestelmän väärinkäytökset',
    26 => 'Tällä lomakkeella voit lähettää sähköpostia valitulle käyttäjälle. Kaikki kentät ovat pakollisia täyttää.',
    27 => 'Lyhyt viesti',
    28 => '%s kirjoitti: ',
    29 => "Tämä on päivittäinen kooste sivustolta {$_CONF['site_name']} käyttäjälle ",
    30 => ' Päivittäinen uutislehti ',
    31 => 'Otsikko',
    32 => 'Päiväys',
    33 => 'Lue artikkeli kokonaan osoitteessa',
    34 => 'Viestin loppu',
    35 => 'Pahoittelemme, käyttäjä ei halua saada sähköposteja.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Laajennettu haku',
    2 => 'Avainsanat',
    3 => 'Aihe',
    4 => 'Kaikki',
    5 => 'Tyyppi',
    6 => 'Artikkelit',
    7 => 'Kommentit',
    8 => 'Kirjoittajat',
    9 => 'Kaikki',
    10 => 'Etsi',
    11 => 'Etsinnän tulokset',
    12 => 'osumaa',
    13 => 'Etsinnän tulokset: ei osumia',
    14 => 'Ei löytynyt hakutuloksia haulle',
    15 => 'Yritä uudelleen.',
    16 => 'Otsikko',
    17 => 'Päiväys',
    18 => 'Kirjoittaja',
    19 => "Etsi nykyisiä ja vanhoja artikkeleita sivuston {$_CONF['site_name']} koko tietokannasta",
    20 => 'Päiväys',
    21 => 'viiva',
    22 => '(Päiväyksen muoto VVVV-KK-PP)',
    23 => 'Katselukertaa',
    24 => 'Löydetty %d aihetta',
    25 => 'Etsitty ',
    26 => 'aihetta ',
    27 => 'sekuntia',
    28 => 'Yksikään artikkeli tai kommentti ei vastannut hakuasi',
    29 => 'Artikkeleiden ja kommenttien tulokset',
    30 => '',
    31 => 'Laajennus ei löytänyt osumia',
    32 => '',
    33 => 'URL',
    34 => 'Sijainti',
    35 => 'Koko päivän',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Hakulauseessa tulee olla ainakin 3 merkkiä.',
    42 => 'Käytä päiväystä muodossa VVVV-KK-PP (vuosi-kuukausi-päivä).',
    43 => 'täsmälleen sama lause',
    44 => 'kaikki sanat',
    45 => 'mikä tahansa sanoista',
    46 => 'Seuraava',
    47 => 'Edellinen',
    48 => 'Kirjoittaja',
    49 => 'Päiväys',
    50 => 'Osumia',
    51 => '',
    52 => 'Sijainti',
    53 => 'Tulokset artikkeleista',
    54 => 'Tulokset kommenteista',
    55 => 'lause',
    56 => 'JA',
    57 => 'TAI',
    58 => 'More results &gt;&gt;',
    59 => 'Results',
    60 => 'per page',
    61 => 'Refine search',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Sivuston tilastot',
    2 => 'Yhteensä latauksia järjestelmästä',
    3 => 'Artikkeleja(kommentteja) järjestelmässä',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Kymmenen luetuinta artikkelia',
    8 => 'Artikkelin otsikko',
    9 => 'Lukukertoja',
    10 => 'Näyttää siltä ettei sivustolla ole artikkeleita tai kukaan ei ole koskaan niitä lukenut.',
    11 => 'Kymmenen kommentoiduinta artikkelia',
    12 => 'Kommentteja',
    13 => 'Näyttää siltä ettei sivustolla ole artikkeleita tai kukaan ei ole kommentoinut niitä.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Kymmenen postitetuinta artikkelia',
    23 => 'Lähetyksiä',
    24 => 'Näyttää siltä ettei kukaan ole lähettänyt sähköpostitse artikkeleita sivustolta.',
    25 => 'Top Ten Trackback Commented Stories',
    26 => 'No trackback comments found.',
    27 => 'Number of active users',
    28 => '',
    29 => '',
    30 => 'Hits',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Aiheeseen liittyen',
    2 => 'Lähetä artikkeli ystävälle',
    3 => 'Tulostettava versio artikkelista',
    4 => 'Artikkelien asetukset',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Lähettääksesi %s sinun täytyy olla kirjautuneena sivustolle.',
    2 => 'Kirjaudu',
    3 => 'Uusi käyttäjä',
    4 => '',
    5 => '',
    6 => 'Lähetä artikkeli',
    7 => 'Kirjautuminen vaaditaan',
    8 => 'Lähetä',
    9 => 'Lähettäessäsi tietoa sivuston käyttöön, seuraa oheisia suosituksia...<ul><li>Täytä kaikki kentät<li>Lähetä täydellistä ja paikkaansapitävää tietoa<li>Tuplatarkista URL-osoitteet</ul>',
    10 => 'Otsikko',
    11 => '',
    12 => 'Aloituspäivä',
    13 => 'Lopetuspäivä',
    14 => 'Sijainti',
    15 => 'Kuvaus',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Lue ensin',
    20 => '',
    21 => '',
    22 => 'Virhe: puuttuvia kenttiä',
    23 => 'Täytä kaikki kentät lomakkeessa. Kaikki kentät ovat pakollisia.',
    24 => 'Lähetys tallennettu',
    25 => '%s -lähetys on tallennettu onnistuneesti.',
    26 => 'Nopeusrajoitus',
    27 => 'Käyttäjänimi',
    28 => 'Aihe',
    29 => 'Juttu',
    30 => 'Viimeisin lähetyksesi oli ',
    31 => " sekuntia sitten. Sivusto vaatii vähintään {$_CONF['speedlimit']} sekunnin tauon lähetysten välillä",
    32 => 'Esikatselu',
    33 => 'Artikkelin esikatselu',
    34 => 'Kirjaudu ulos',
    35 => 'HTML koodit eivät ole sallittu',
    36 => 'Lähetystila',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Osoiterivi 1',
    45 => 'Osoiterivi 2',
    46 => 'Kaupunki',
    47 => 'Osavaltio',
    48 => 'Postinumero',
    49 => '',
    50 => '',
    51 => 'Sijainti',
    52 => 'Poista',
    53 => 'Luo tili',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Tunnistus vaaditaan',
    2 => 'Evätty! Virheelliset kirjautumistiedot',
    3 => 'Väärä salasana käyttäjälle',
    4 => 'Käyttäjätunnus:',
    5 => 'Salasana:',
    6 => 'Kaikki ylläpidon osioiden liikenne sivustolla kirjataan ja tarkistetaan. <br' . XHTML . '>Sivu on tarkoitettu vain sallitulle henkilökunnalle.',
    7 => 'kirjaudu'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Riittämättömät ylläpidolliset valtuudet',
    2 => 'Sinulla ei ole oikeuksia muokata tätä lohkoa.',
    3 => 'Lohkojen muokkaus',
    4 => 'There was a problem reading this feed (see error.log for details).',
    5 => '',
    6 => '',
    7 => 'Kaikki',
    8 => 'Lohkon turvallisuustaso',
    9 => 'Lohkon lajittelu',
    10 => '',
    11 => 'Sivuston lohko',
    12 => 'Normaali lohko',
    13 => 'Sivuston lohkojen asetukset',
    14 => 'RDF URL',
    15 => 'Viimeisin RDF päivitys',
    16 => 'Normaalin lohkon asetukset',
    17 => 'Lohkon sisältö',
    18 => 'Täytä lohkon otsikko, turvallisuus taso sekä sisältö -kentät',
    19 => 'Lohkojen hallinta',
    20 => '',
    21 => 'Lohkon turvataso',
    22 => '',
    23 => 'Lajittelujärjestys',
    24 => '',
    25 => 'Muokataksesi tai poistaaksesi lohkoa, klikkaa haluamaasi lohkoa alta. Luodaksesi uuden lohkon, klikkaa uusi lohko yläpuolelta.',
    26 => 'Ulkoasu lohko',
    27 => 'PHP lohko',
    28 => 'PHP lohkon asetukset',
    29 => 'Lohkon toiminnot',
    30 => 'Jos haluat lohkon käyttävän PHP koodia, syötä funktion nimi ylhäälle. Funktion tai toiminteen tulee alkaa "phpblock_" (esimerkiksi phpblock_getweather). Jos aliohjelmassa ei ole tätä alkulausetta, funktiota ei kutsuta.  Tämä tehdään epämääräisten aliohjelmakutsujen estämiseksi jos henkilöt ovat hakkeroineet Geeklogin asennuksen. Varmista ettet laita tyhjiä sulkuja "()" funktion nimen perään. Lopuksi on suositeltavaa laittaa kaikki PHP koodisi tiedostoon /path/to/geeklog/system/lib-custom.php.  Tällä varmistut että koodisi säilyy vaikka päivittäisit Geeklogin uudempaan versioon.',
    31 => 'Virhe PHP lohkossa.  Funktio, %s, ei ole olemassa.',
    32 => 'Virhe puuttuva kenttä',
    33 => 'Sinun tulee syöttää URL .rdf tiedostoon sivuston lohkoa varten',
    34 => 'Sinun tulee syöttää otsikko ja funktio PHP lohkoa varten',
    35 => 'Sinun tulee syöttää otsikko ja sisältö normaali lohkoihin',
    36 => 'Sinun tulee syöttää sisältö ulkoasu lohkoa varten',
    37 => 'Virheellinen PHP lohkon funktion nimi',
    38 => 'PHP lohkojen funktioissa tulee olla alussa \'phpblock_\' (esim. phpblock_getweather).  \'phpblock_\' etuliite vaaditaan turvallisuuden vuoksi, hämärän koodin ajamisen estämiseksi.',
    39 => 'Sivu',
    40 => 'Vasen',
    41 => 'Oikea',
    42 => 'Lajittelujärjestys ja turvallisuustaso tulee syöttää Geeklogin oletuslohkoja varten',
    43 => 'Vain kotisivu',
    44 => '',
    45 => "Olet yrittämässä käyttää lohkoa johon sinulla ei ole oikeuksia. Yritys on kirjattu lokitiedostoon.  <a href=\"{$_CONF['site_admin_url']}/block.php\">Siirry takaisin ylläpidon valikkoon</a>.",
    46 => 'Uusi lohko',
    47 => '',
    48 => 'Lohkon nimi',
    49 => ' (ei välilyöntejä ja nimen tulee olla yksilöllinen)',
    50 => '',
    51 => 'sisällytä http://',
    52 => 'Jos jätät tämän tyhjäksi, avuste-ikonia ei näytetä tälle lohkolle',
    53 => 'Päällä',
    54 => 'tallenna',
    55 => 'peruuta',
    56 => 'poista',
    57 => 'Siirrä lohkoa alaspäin',
    58 => 'Siirrä lohkoa ylöspäin',
    59 => 'Siirrä lohko oikealle puolelle',
    60 => 'Siirrä lohko vasemmalle puolelle',
    61 => 'No Title',
    62 => 'Article Limit',
    63 => 'Bad Block Title',
    64 => 'Your Title must not be empty and cannot contain HTML!',
    65 => 'Order',
    66 => 'Autotags',
    67 => 'Check to allow autotags',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Aikaisemmat artikkelit',
    2 => 'Seuraavat artikkelit',
    3 => 'Tila',
    4 => 'Lähetystila',
    5 => 'Artikkelin muokkaus',
    6 => 'Ei artikkeleja järjestelmässä',
    7 => 'Kirjoittaja',
    8 => 'tallenna',
    9 => 'esikatselu',
    10 => 'peruuta',
    11 => 'poista',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Päiväys',
    16 => 'Alkuteksti',
    17 => 'Leipäteksti',
    18 => 'Osumia',
    19 => 'Kommentteja',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => 'Lista artikkeleista',
    23 => 'Muokataksesi tai poistaaksesi artikkelin, klikkaa artikkelin numeroa. Nähdäksesi artikkelin, klikkaa haluamaasi otsikkoa. Luodaksesi uuden artikkelin, valitse uusi artikkeli.',
    24 => 'The ID you chose for this story is already in use. Please use another ID.',
    25 => 'Error when saving story',
    26 => 'Artikkelin esikatselu',
    27 => 'If you use [unscaledX] instead of [imageX], the image will be inserted at its original dimensions.',
    28 => '<p><b>PREVIEWING</b>: Previewing a story with images attached is best done by saving the article as a draft INSTEAD OF hitting the preview button.  Use the preview button only when images are not attached.',
    29 => 'Trackbacks',
    30 => 'Tiedoston lähetys-virhe',
    31 => 'Täytä otsikko ja alkuteksti kentät',
    32 => 'Erikoisartikkeli',
    33 => 'Vain yksi artikkeli voi olla erikoisena',
    34 => 'Vedos',
    35 => 'Kyllä',
    36 => 'Ei',
    37 => 'Lisää',
    38 => 'Lisää',
    39 => 'Lähetyksiä',
    40 => '',
    41 => "Yrität ladata artikkelia johon sinulla ei ole oikeuksia. Yritys on kirjattu lokitiedostoon. Voit nähdä artikkelin vain luku-muodossa. <a href=\"{$_CONF['site_admin_url']}/story.php\">Siirry takaisin artikkelien ylläpitoon</a> kun olet valmis.",
    42 => "Yrität ladata artikkelia johon sinulla ei ole oikeuksia. Yritys on kirjattu lokitiedostoon. <a href=\"{$_CONF['site_admin_url']}/story.php\">Siirry takaisin artikkelien ylläpitoon</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>HUOMAA:</b> jos muokkaat päiväystä osoittamaan tulevaisuuteen, artikkelia ei julkaista ennen kyseistä päivää. Artikkelia ei myöskään sisällytetä RDF otsikoihin, hakuihin tai tilastoihin.',
    47 => 'Kuvat',
    48 => 'kuva',
    49 => 'oikea',
    50 => 'vasen',
    51 => 'Lisätäksesi kuvan artikkeliin, tekstin joukkoon tulee lisätä erikoistekstiä. Erikoistekstejä ovat [imageX], [imageX_right] tai [imageX_left] jossa X on kuvan numero jonka olet liittänyt. HUOMAA: Sinun tulee käyttää kuvia jotka itse liität artikkeliin, muuten et voi tallentaa artikkelia.<BR><P><B>ESIKATSELU</B>: Esikatselu kuvien kanssa onnistuu parhaiten tallentamalla artikkeli aluksi vedoksena EIKÄ painamalla esikatselu-nappia. Käytä esikatselua vain kun kuvia ei ole liitettynä.',
    52 => '',
    53 => 'ei käytetty. Sinun tulee sisällyttää tämä kuva alkutekstiin tai leipätekstiin ennen kuin voit tallentaa muutokset',
    54 => 'Liitetyt kuvat joita ei käytetty',
    55 => 'Seuraavat virheet tapahtuivat tallennettaessa. Korjaa virheet ennen tallentamista',
    56 => 'Näytä aihe kuvake',
    57 => 'Näytä skaalaamaton kuva',
    58 => 'Story Management',
    59 => 'Option',
    60 => '',
    61 => 'Auto Archive',
    62 => 'Auto Delete',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Expand the Content Edit Area size',
    68 => 'Reduce the Content Edit Area size',
    69 => 'Publish Story Date',
    70 => 'Toolbar Selection',
    71 => 'Basic Toolbar',
    72 => 'Common Toolbar',
    73 => 'Advanced Toolbar',
    74 => 'Advanced II Toolbar',
    75 => 'Full Featured',
    76 => 'Publish Options',
    77 => 'Javascript needs to be enabled for Advanced Editor. Option can be disabled in the main site config.php',
    78 => 'Click <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">here</a> to use default editor',
    79 => 'Preview',
    80 => 'Editor',
    81 => 'Publish Options',
    82 => 'Images',
    83 => 'Archive Options',
    84 => 'Permissions',
    85 => 'Show All',
    86 => 'Advanced Editor',
    87 => 'Story Stats',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Aihepiirien muokkaus',
    2 => 'Aiheen ID',
    3 => 'Aihepiirin nimi',
    4 => 'Aiheen kuva',
    5 => '(älä käytä välilyöntejä)',
    6 => 'Aihepiirin poistaminen poistaa kaikki aihepiirin artikkelit ja lohkot jotka siihen liittyvät',
    7 => 'Täytä Aiheen ID ja Aihepiirin nimi -kentät',
    8 => 'Aihepiirien hallinta',
    9 => 'Klikkaa aihepiiriä muokataksesi tai poistaaksesi aiheen. Luodaksesi uuden valitse uusi aihepiiri -nappi vasemmalta. Näet käyttöoikeutesi aihepiiriin suluissa. Tähti (*) merkitsee oletusaihetta.',
    10 => 'Lajittelujärjestys',
    11 => 'Artikkeleja/sivu',
    12 => 'Pääsy kielletty',
    13 => "Olet pyrkimässä aiheeseen johon sinulla ei ole oikeuksia. Yritys on kirjattu lokitiedostoon. <a href=\"{$_CONF['site_admin_url']}/topic.php\">Siirry takaisin aihepiirien ylläpitoon</a>.",
    14 => 'Lajittelu tapa',
    15 => 'aakkosellinen',
    16 => 'oletus on',
    17 => 'Uusi aihepiiri',
    18 => 'Ylläpidon sivu',
    19 => 'tallenna',
    20 => 'peruuta',
    21 => 'poista',
    22 => 'Oletus',
    23 => 'tee tästä oletus aihe uusille artikkeleille',
    24 => '(*)',
    25 => 'Archive Topic',
    26 => 'make this the default topic for archived stories. Only one topic allowed.',
    27 => 'Or Upload Topic Icon',
    28 => 'Maximum',
    29 => 'File Upload Errors',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Käyttäjän muokkaus',
    2 => 'Käyttäjän ID',
    3 => 'Käyttäjätunnus',
    4 => 'Koko nimi',
    5 => 'Salasana',
    6 => 'Turvallisuustaso',
    7 => 'Sähköposti-osoite',
    8 => 'Kotisivu',
    9 => '(älä käytä välilyöntejä)',
    10 => 'Täytä käyttäjätunnus ja sähköposti-osoite kentät',
    11 => 'Käyttäjien hallinta',
    12 => 'Klikkaa alta jos haluat muokata tai poistaa käyttäjän. Luodaksesi uuden käyttäjän, valitse uusi käyttäjä vasemmalta. Voit tehdä yksinkertaisia hakuja syöttämällä osan käyttäjätunnuksesta, sähköpostista tai kokonimestä allaolevaan lomakkeeseen (esimerkiksi *son* tai *.edu).',
    13 => 'Turvataso',
    14 => 'Rek.päivä',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'tallenna',
    21 => 'Käyttäjätunnus on jo olemassa.',
    22 => 'Virhe',
    23 => 'Kimppalisäys',
    24 => 'Tuo lauma käyttäjiä',
    25 => 'Voit tuoda Geeklogiin suuremman määrän käyttäjiä. Tuontitiedoston tulee olla sarkain-eroteltu teksti-tiedosto jossa kenttien tulee olla seuraavassa järjestyksessä: koko nimi, käyttäjätunnus, sähköposti-osoite. Tuomillesi henkilöille postitetaan satunnaisesti generoitu salasana sähköpostitse. Tiedostossa tulee olla yksi käyttäjä per rivi. Virheet tuonnissa voivat aiheuttaa ongelmia joiden selvittäminen vaatii käsityötä joten tarkista syötteesi tarkasti!',
    26 => '',
    27 => '',
    28 => 'Klikkaa tähän tuhotaksesi tämän kuvan',
    29 => 'Polku',
    30 => 'Tuo',
    31 => 'Uudet käyttäjät',
    32 => 'Käsittely valmis. Tuotiin %d ja kohdattiin %d virhettä',
    33 => 'lähetä',
    34 => 'Virhe: valitse lähetettävä tiedosto.',
    35 => 'Viimeksi kirjautunut',
    36 => '(ei koskaan)',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Banned',
    43 => 'Awaiting Activation',
    44 => 'Awaiting Authorization',
    45 => 'Active',
    46 => 'User Status',
    47 => 'Edit',
    48 => 'Show Admin Groups',
    49 => 'Admin Group',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Days',
    52 => '<br' . XHTML . '>Note: "Online Days" is the number of days between the first registration and the last login.',
    53 => 'registered',
    54 => 'Batch Delete',
    55 => 'This only works if you have <code>$_CONF[\'lastlogin\'] = true;</code> in your config.php',
    56 => 'Please choose the type of user you want to delete and press "Update List". Then, uncheck those from the list you do not want to delete and press "Delete". Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom users',
    58 => 'Short-Time Users',
    59 => 'Old Users',
    60 => 'Users that registered more than ',
    61 => ' months ago, but never logged in.',
    62 => 'Users that registered more than ',
    63 => ' months ago, then logged in within 24 hours, but since then never came back to your site.',
    64 => 'Normal users, who simply did not visit your site since ',
    65 => ' months.',
    66 => 'Update List',
    67 => 'Months since registration',
    68 => 'Online Hours',
    69 => 'Offline Months',
    70 => 'could not be deleted',
    71 => 'sucessfully deleted',
    72 => 'No User selected for deletion',
    73 => 'Are You sure you want to permanently delete ALL selected users?',
    74 => 'Recent Users',
    75 => 'Users that registered in the last ',
    76 => ' months',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Hyväksy',
    2 => 'Poista',
    3 => 'Muokkaa',
    4 => 'Profiili',
    10 => 'Otsikko',
    11 => 'Aloitus päivä',
    12 => 'URL',
    13 => 'Aihepiiri',
    14 => 'Päivä',
    15 => 'Aihe',
    16 => 'Käyttäjänimi',
    17 => 'Koko nimi',
    18 => 'Sähköposti',
    34 => 'Komennot ja hallinta',
    35 => 'Lähetettyjä artikkeleja',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Lähetä',
    39 => 'Ei hallinnoitavia lähetyksiä tällä hetkellä',
    40 => 'Käyttäjien lähetyksiä',
    41 => 'Comment Submissions',
    42 => 'User Name',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} Posti Apuri",
    2 => 'Lähettäjä',
    3 => 'Vastausosoite',
    4 => 'Aihe',
    5 => 'Leipäteksti',
    6 => 'Kenelle lähetetään:',
    7 => 'Kaikille käyttäjille',
    8 => 'Ylläpito',
    9 => 'Vaihtoehdot',
    10 => 'HTML',
    11 => 'Tärkeä viesti!',
    12 => 'Lähetä',
    13 => 'Tyhjennä',
    14 => 'Ohita käyttäjien asetukset',
    15 => 'Virhe lähetettäessä: ',
    16 => 'Lähetykset tehty onnistuneesti: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Lähetä toinen viesti</a>",
    18 => 'Vastaanottaja',
    19 => 'HUOMAA: jos haluat lähettää viestin sivuston kaikille jäsenille, valitse kirjautuneet käyttäjät -ryhmä pudotusvalikosta.',
    20 => "Onnistuneesti lähetetty <successcount> viestiä ja epäonnistuttu <failcount> viestin lähetyksessä. Tarvittaessa kaikkien viestilähetyksien tiedot löytyvät alta. Muuten voit lähettää <a href=\"{$_CONF['site_admin_url']}/mail.php\">seuraavan viestin</a> tai <a href=\"{$_CONF['site_admin_url']}/moderation.php\">siirtyä takaisin hallinnon sivulle</a>.",
    21 => 'epäonnistumisia',
    22 => 'onnistumisia',
    23 => 'Ei epäonnistumisia',
    24 => 'Ei onnistumisia',
    25 => '-- Valitse ryhmä --',
    26 => 'Täytä kaikki kentät lomakkeesta ja valitse kohdekäyttäjien ryhmä pudotusvalikosta.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Laajennusten asentaminen voi vahingoittaa Geeklogia ja mahdollisesti järjestelmääsi. Käytä vain <a href="http://www.geeklog.net" target="_blank">Geeklogin kotisivulta</a> ladattuja laajennuksia, koska testaamme sivustollemme lähetetyt laajennukset usealla käyttöjärjestelmällä. On tärkeää ymmärtää laajennuksien asentamisen vaativan joidenkin käyttöjärjestelmiäkäskyjen ajamisen, jotka voivat johtaa turvallisuusongelmiin, varsinkin kolmansien osapuolien laajennusten tapauksessa. Vaikka varoitammekin käyttäjiä laajennuksista, emme takaa asennuksen onnistumista emmekä ota vastuuta Geeklogin laajennusten aiheuttamista vahingoista. Toisinsanoen, asenna näitä omalla vastuullasi. Varovaisille; käsin tapahtuvaan asennukseen tulee ohjeet jokaisessa laajennuspaketissa.',
    2 => 'Huomioi laajennuksia asentaessasi',
    3 => 'Laajennuksien asentamislomake',
    4 => 'Laajennustiedosto',
    5 => 'Lista laajennuksista',
    6 => 'Varoitus: laajennus on jo asennettu!',
    7 => 'Laajennus jonka asentamista yrität, on jo asennettu. Poista laajennus ennen sen uudelleenasentamista',
    8 => 'Laajennuksen yhteensopivuustesti epäonnistui',
    9 => 'Laajennus vaatii uudemman version Geeklogista. Päivitä <a href="http://www.geeklog.net">Geeklog-järjestelmäsi</a> tai hanki uudempi versio laajennuksesta.',
    10 => '<br' . XHTML . '><b>Laajennuksia ei ole tällä hetkellä asennettuna.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'Muokataksesi tai poistaaksesi laajennuksen, valitse laajennuksen numero. Halutessasi lisätietoja laajennuksesta, valitse laajennuksen nimi alta ja sinut ohjataa laajennuksen kotisivulle. Asentaaksesi tai päivittääksesi laajennuksen, lue laajennuksen dokumentaatio.',
    12 => 'laajennuksen nimeä ei ole lähetetty plugineditor()',
    13 => 'Laajennusten muokkain',
    14 => 'Uusi laajennus',
    15 => 'Hallinnon sivu',
    16 => 'Laajennuksen nimi',
    17 => 'Laajennuksen versio',
    18 => 'Geeklogin versio',
    19 => 'Päällä',
    20 => 'Kyllä',
    21 => 'Ei',
    22 => 'Asenna',
    23 => 'Tallenna',
    24 => 'Peruuta',
    25 => 'Poista',
    26 => 'Laajennuksen nimi',
    27 => 'Laajennuksen kotisivu',
    28 => 'Laajennuksen versio',
    29 => 'Geeklogin versio',
    30 => 'Poista laajennus?',
    31 => 'Oletko varma että haluat poistaa laajennuksen? Poistamalla poistat myös kaiken tiedot ja tietorakenteen jotka liittyvät tähän laajennukseen. Jos olet varma, valitse poista uudelleen alta löytyvästä lomakkeesta.',
    32 => '<p><b>Error AutoLink tag not correct format</b></p>',
    33 => 'Code Version',
    34 => 'Update',
    35 => 'Edit',
    36 => 'Code',
    37 => 'Data',
    38 => 'Update!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'luo syöte',
    2 => 'tallenna',
    3 => 'poista',
    4 => 'peruuta',
    10 => 'Sisällön syndikointi',
    11 => 'Uusi syöte',
    12 => 'Ylläpidon sivu',
    13 => 'Poistaaksesi tai muokataksesi syötettä, valitse syötteen otsikko. Luodaksesi uuden syötteen, valitse Uusi syöte yltä.',
    14 => 'Otsikko',
    15 => 'Tyyppi',
    16 => 'Tiedosto',
    17 => 'Muoto',
    18 => 'viimeksi päivitetty',
    19 => 'Sallittu',
    20 => 'Kyllä',
    21 => 'Ei',
    22 => '<i>(ei syötteitä)</i>',
    23 => 'kaikki artikkelit',
    24 => 'Syötteiden muokkain',
    25 => 'Syötteen otsikko',
    26 => 'Rajoitus',
    27 => 'Sisällön pituus',
    28 => '(0 = ei tekstiä, 1 = koko teksti, muu = rajoita syöttämääsi määrään merkkejä.)',
    29 => 'Kuvaus',
    30 => 'Viimeisin päivitys',
    31 => 'Merkkilaji',
    32 => 'Kieli',
    33 => 'Sisältö',
    34 => 'Kirjauksia',
    35 => 'Tuntia',
    36 => 'Valitse syötteen tyyppi',
    37 => '',
    38 => 'Virhe: puuttuvia kenttiä',
    39 => 'Täytä syötteen otsikko, kuvaus ja tiedoston nimi.',
    40 => 'Syötä kirjauksien määrä tai tuntien lukumäärä.',
    41 => 'Linkit',
    42 => '',
    43 => 'All',
    44 => 'None',
    45 => 'Header-link in topic',
    46 => 'Limit Results',
    47 => 'Search',
    48 => 'Edit',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'Error: existing Filename',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Salasanasi on lähetetty sähköpostitse ja pitäisi saapua sinulle hetken kuluttua. Seuraa viestissä olevia ohjeita. Kiitämme sivuston {$_CONF['site_name']} käytöstä.",
    2 => "Kiitokset artikkelin lähettämisestä sivustolle {$_CONF['site_name']}.  Ylläpito tarkistaa ja läpikäy sen ja se tulee hyväksymisen jälkeen lukijoiden näkyville sivustolle.",
    3 => '',
    4 => '',
    5 => 'Tilisi tiedot ovat tallennettu.',
    6 => 'Näyttöasetuksesi ovat tallennettu.',
    7 => 'Kommennttisi asetukset ovat tallennettu.',
    8 => 'Olet kirjautunut ulos.',
    9 => 'Artikkelisi on tallennettu.',
    10 => 'Artikkelisi on poistettu.',
    11 => 'Lohko on tallennettu.',
    12 => 'Lohko on poistettu.',
    13 => 'Aiheesi on tallennettu.',
    14 => 'Aihe ja kaikki sen artikkelit ja lohkot ovat poistettu.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Uusi käyttäjä on tallennettu.',
    22 => 'Käyttäjä on poistettu.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Viesti lähetetty onnistuneesti.',
    28 => 'Laajennus on tallennettu',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Pääsy kielletty',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Järjestelmän viesti',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Laajennus on onnistuneesti asennettu!',
    45 => 'Laajennus on poistettu.',
    46 => '',
    47 => 'Tämä toiminto toimii vain *nix järjestelmissä.  Jos käyttöjärjestelmäsi on *nix, välimuisti on tyhjennetty. Jos käyttöjärjestelmäsi on Windows, joudut etsimään tiedostot adodb_*.php ja poistamaan ne käsin.',
    48 => "Kiitos jäsenhakemuksestasi sivustolle {$_CONF['site_name']}. Ylläpito käy läpi hakemuksesi. Hyväksymisen jälkeen salasanasi lähetetään antamaasi sähköpostiosoitteeseen.",
    49 => 'Ryhmä on tallennettu.',
    50 => 'Ryhmä on poistettu.',
    51 => 'Käyttäjänimi on jo käytössä. Valitse toinen käyttäjänimi.',
    52 => 'Syöttämäsi sähköpostiosoite ei ole oikea.',
    53 => 'Uusi salasanasi on hyväksytty. Käytä uutta salasanaasi kirjautuessasi nyt sisään.',
    54 => 'Pyyntösi uuden salasanan saamiseksi on ikääntynyt. Yritä uudestaan alta.',
    55 => 'Sähköpostiviesti on lähetetty sinulle ja sen pitäisi saapua hetken päästä. Seuraa viestin ohjeita asettaaksesi uuden salasanan tilillesi.',
    56 => 'Syöttämäsi sähköpostiosoite on jo käytössä toisella tilillä.',
    57 => 'Tilisi on poistettu.',
    58 => 'Syötteesi on tallennettu.',
    59 => 'Syöte on poistettu.',
    60 => 'The plugin was successfully updated',
    61 => 'Plugin %s: Unknown message placeholder',
    62 => 'The trackback comment has been deleted.',
    63 => 'An error occurred when deleting the trackback comment.',
    64 => 'Your trackback comment has been successfully sent.',
    65 => 'Weblog directory service successfully saved.',
    66 => 'The weblog directory service has been deleted.',
    67 => 'The new password does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'Your account has been blocked!',
    70 => 'Your account is awaiting administrator approval.',
    71 => 'Your account has now been confirmed and is awaiting administrator approval.',
    72 => 'An error occured while attempting to install the plugin. See error.log for details.',
    73 => 'An error occured while attempting to uninstall the plugin. See error.log for details.',
    74 => 'The pingback has been successfully sent.',
    75 => 'Trackbacks must be sent using a POST request.',
    76 => 'Do you really want to delete this item?',
    77 => 'WARNING:<br' . XHTML . '>You have set your default encoding to UTF-8. However, your server does not support multibyte encodings. Please install mbstring functions for PHP or choose a different character set/language.',
    78 => 'Please make sure that the email address and the confirmation email address are the same.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Please try logging in again below.',
    82 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    83 => 'To change your password, email address, or for how long to remember you, please enter your current password.',
    84 => 'To delete your account, please enter your current password.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Pääsy',
    'ownerroot' => 'Omistaja/Root',
    'group' => 'Ryhmä',
    'readonly' => 'Vain luku',
    'accessrights' => 'Käyttöoikeudet',
    'owner' => 'Omistaja',
    'grantgrouplabel' => 'Salli ryhmälle muokkaus oikeudet',
    'permmsg' => 'HUOMAA: jäsenet tarkoittavat kaikkia sivustolle kirjautuneita henkilöitä ja tuntematon tarkoittaa kaikkia sivustolla selailevia käyttäjiä jotka eivät ole kirjautuneet sisään.',
    'securitygroups' => 'Turvallisuus ryhmät',
    'editrootmsg' => "Vaikka olet käyttäjien ylläpitäjä, et voi muokata pääkäyttäjää olematta itse pääkäyttäjä. Voit muokata muita käyttäjiä paitsi pääylläpitäjää. Huomaa että kaikki yritykset laittomasti muokata pääkäyttäjiä kirjoitetaan lokitiedostoon. Siirry takaisin <a href=\"{$_CONF['site_admin_url']}/user.php\">käyttäjien ylläpitoon</a>.",
    'securitygroupsmsg' => 'Rastita ruudut niistä ryhmistä joihin haluat käyttäjän kuuluvan.',
    'groupeditor' => 'Ryhmien muokkaus',
    'description' => 'Kuvaus',
    'name' => 'Nimi',
    'rights' => 'Oikeudet',
    'missingfields' => 'Puuttuvat kentät',
    'missingfieldsmsg' => 'Syötä ryhmän nimi ja kuvaus',
    'groupmanager' => 'Ryhmien hallinta',
    'newgroupmsg' => 'Muokataksesi tai poistaaksesi ryhmän, valitse ryhmä alta. Luodaksesi uuden ryhmän, valitse uusi ryhmä yltä. Huomaa että ydinryhmiä ei voi poistaa koska ne ovat järjestelmän käytössä.',
    'groupname' => 'Ryhmän nimi',
    'coregroup' => 'Ydin ryhmä',
    'yes' => 'Kyllä',
    'no' => 'Ei',
    'corerightsdescr' => "Ryhmä kuuluu sivuston {$_CONF['site_name']} ydin ryhmään. Ryhmän oikeuksia ei voi siitä syystä muokata. Alla on lista ryhmän oikeuksista vain lukemista varten.",
    'groupmsg' => 'Turvallisuus ryhmät sivustolla ovat hierarkiset. Muokkaamalla tätä ryhmää tai jotain alla olevista ryhmistä antaa tälle ryhmälle samat oikeudet kuin muille alla oleville ryhmille. Milloin se on mahdollista, suosittelemme käyttämään allaolevia ryhmiä oikeuksie jakamiseen tälle ryhmälle. Jos tarvitset muokattuja oikeuksia, voit valita oikeudet sivuston eri toimintoihin alta löytyvästä \'Oikeudet\'-kohdasta. Lisätäksesi tämän ryhmän johonkin allaolevista ryhmistä, merkitse rasti ryhmän tai ryhmien viereen.',
    'coregroupmsg' => "Tämä ryhmä on ydinryhmä sivustolla {$_CONF['site_name']}.  Tästä johtuen ryhmää ei voi muokata. Alla on lista vain luku-muodossa ryhmistä joihin tämä ryhmä kuuluu.",
    'rightsdescr' => 'Ryhmä saa oikeutensa joko olemalla osana toista ryhmää TAI ryhmälle voi antaa suoraan haluamasi oikeudet. Alla olevat oikeudet joissa ei ole rastiruutua, ovat oikeuksia jotka ryhmä on saanut olemalla osa jotain toista ryhmää jolla nuo oikeudet ovat. Ne joissa on laatikko vieressä ovat oikeuksia joita ryhmälle voidaan suoraan myöntää.',
    'lock' => 'Lukittu',
    'members' => 'Jäsenet',
    'anonymous' => 'Tuntematon',
    'permissions' => 'Oikeudet',
    'permissionskey' => 'L = luku, M = muokkaa, muokkaus-oikeudet olettavat myös luku oikeuksien löytyvän',
    'edit' => 'Muokkaa',
    'none' => 'Ei yhtään',
    'accessdenied' => 'Pääsy kielletty',
    'storydenialmsg' => "Sinulla ei ole oikeuksia katsoa artikkelia. Oletko varmasti jäsenenä sivustolla {$_CONF['site_name']}? <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Rekisteröidy jäseneksi</a> sivustolle {$_CONF['site_name']} saadaksesi täydet jäsenyyden suomat oikeudet!",
    'nogroupsforcoregroup' => 'Ryhmä ei kuulu mihinkään muuhun ryhmään',
    'grouphasnorights' => 'Ryhmällä ei ole hallinnointi oikeuksia sivustolla.',
    'newgroup' => 'Uusi ryhmä',
    'adminhome' => 'Ylläpidon sivu',
    'save' => 'tallenna',
    'cancel' => 'peruuta',
    'delete' => 'poista',
    'canteditroot' => 'Olet yrittänyt muokata Omistajien ryhmää, mutta et kuulu itse ryhmään, niinpä sinulta on pääsy ryhmään kielletty. Ota yhteyttä järjestelmän ylläpitoon jos uskot tämän olevan virhe',
    'listusers' => 'Listaa käyttäjät',
    'listthem' => 'lista',
    'usersingroup' => 'Käyttäjät ryhmässä %s',
    'usergroupadmin' => 'Käyttäjäryhmien ylläpito',
    'add' => 'Lisää',
    'remove' => 'Poista',
    'availmembers' => 'Saatavilla olevat jäsenet',
    'groupmembers' => 'Ryhmän jäsenet',
    'canteditgroup' => 'Sinun tulee olla ryhmän jäsen muokataksesi tätä ryhmää. Jos tämä tuntuu virheeltä, ota yhteyttä järjestelmän ylläpitoon.',
    'cantlistgroup' => 'To see the members of this group, you have to be a member yourself. Please contact the system administrator if you feel this is an error.',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Search',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Group ID',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Group name already exists',
    'groupexistsmsg' => 'There is already a group with this name. Group names must be unique.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Viimeiset 10 varmuuskopiota',
    'do_backup' => 'Tee varmuuskopio',
    'backup_successful' => 'Tietokannan varmistus onnistui.',
    'db_explanation' => 'Luodaksesi uuden varmuuskopion Geeklogista, klikkaa alta löytyvää nappia',
    'not_found' => "Viallinen polku tai mysqldump apuohjelma ei ole suoritettavissa.<br" . XHTML . ">Tarkista <strong>\$_DB_mysqldump_path</strong> määritys config.php -tiedostossa.<br" . XHTML . ">Muuttujan nykyinen määrittely: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Varmuuskopiointi epäonnistui: tiedoston koko 0 tavua',
    'path_not_found' => "{$_CONF['backup_path']} ei ole olemassa tai ei ole hakemisto",
    'no_access' => "VIRHE: Hakemisto {$_CONF['backup_path']} ei ole saatavilla.",
    'backup_file' => 'Tee varmuuskopio',
    'size' => 'Koko',
    'bytes' => 'tavua',
    'total_number' => 'Varmistuksia yhteensä: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Etusivu',
    2 => 'Yhteystiedot',
    3 => 'Julkaise',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Sivuston tilastot',
    8 => 'Mukauta',
    9 => 'Etsi',
    10 => 'laajennettu haku',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Virhe',
    2 => 'Oho, etsin kaikkialta, mutten löytänyt <b>%s</b>.',
    3 => "<p>Pahoittelumme mutta emme löydä haluamaasi tiedostoa. Katso sivuston <a href=\"{$_CONF['site_url']}\">pääsivu</a> tai sivuston <a href=\"{$_CONF['site_url']}/search.php\">hakusivu</a> löytääksesi mitä olet hukannut."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Kirjautuminen vaaditaan',
    2 => 'Tämä alue vaatii sisäänkirjautumisen käyttäjänä.',
    3 => 'Kirjaudu',
    4 => 'Uusi käyttäjä'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'from',
    'tracked_on' => 'Tracked on',
    'read_more' => '[read more]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'No trackback comments for this entry.',
    'this_trackback_url' => 'Trackback URL for this entry:',
    'num_comments' => '%d trackback comments',
    'send_trackback' => 'Send Pings',
    'preview' => 'Preview',
    'editor_title' => 'Send trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Send',
    'button_preview' => 'Preview',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'No Trackback URL',
    'target_required' => 'Please enter a trackback URL',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Select Trackback URL',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to send your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to send your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not send a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Send Pings',
    'send_pings_for' => 'Send Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'Resend',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or send a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Send Pingback',
    'pingback_short' => 'Send Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Send Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Send Trackback',
    'trackback_short' => 'Send a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that sending Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To send a trackback comment for a story, go to the list of stories and click on "Send Ping" for the story. To send a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to send the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To send a pingback for a story, go to the list of stories and click on "Send Ping" for the story. To send a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when sending the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Directory',
    'title_year' => 'Article Directory for %d',
    'title_month_year' => 'Article Directory for %s %d',
    'nav_top' => 'Back to Article Directory',
    'no_articles' => 'No articles.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n new %i in the last %t %s',
    'new_last' => 'last %t %s',
    'minutes' => 'minutes',
    'hours' => 'hours',
    'days' => 'days',
    'weeks' => 'weeks',
    'months' => 'months',
    'minute' => 'minute',
    'hour' => 'hour',
    'day' => 'day',
    'week' => 'week',
    'month' => 'month'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Tammikuu',
    2 => 'Helmikuu',
    3 => 'Maaliskuu',
    4 => 'Huhtikuu',
    5 => 'Toukokuu',
    6 => 'Kesäkuu',
    7 => 'Heinäkuu',
    8 => 'Elokuu',
    9 => 'Syyskuu',
    10 => 'Lokakuu',
    11 => 'Marraskuu',
    12 => 'Joulukuu'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Sunnuntai',
    2 => 'Maanantai',
    3 => 'Tiistai',
    4 => 'Keskiviikko',
    5 => 'Torstai',
    6 => 'Perjantai',
    7 => 'Lauantai'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Search',
    'limit_results' => 'Limit Results',
    'submit' => 'Submit',
    'edit' => 'Edit',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => 'Admin Home',
    'create_new' => 'Create New',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => 'Enabled',
    'title' => 'Title',
    'type' => 'Type',
    'topic' => 'Topic',
    'help_url' => 'Help File URL',
    'save' => 'Save',
    'cancel' => 'Cancel',
    'delete' => 'Delete',
    'delete_sel' => 'Delete selected',
    'copy' => 'Copy',
    'no_results' => '- No entries found -',
    'data_error' => 'There was an error processing the subscription data. Please check the data source.',
    'preview' => 'Preview',
    'records_found' => 'Records found',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Comments Enabled',
    -1 => 'Comments Disabled',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Hour',
    7200 => '2 Hours',
    10800 => '3 Hours',
    28800 => '8 Hours',
    86400 => '1 Day',
    604800 => '1 Week',
    2678400 => '1 Month'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Not Featured',
    1 => 'Featured'
);

$LANG_frontpagecodes = array(
    0 => 'Show Only in Topic',
    1 => 'Show on Front Page'
);

$LANG_postmodes = array(
    'plaintext' => 'Plain Old Text',
    'html' => 'HTML Formatted'
);

$LANG_sortcodes = array(
    'ASC' => 'Oldest First',
    'DESC' => 'Newest First'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Enabled',
    -1 => 'Trackback Disabled'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating Allowed',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autolinks?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2)
);

?>
